import 'vuetify/dist/vuetify.min.css'
import '@mdi/font/css/materialdesignicons.css'

import Notifications from '@remotehq/vue-notification'
import i18next from 'i18next'
import Backend from 'i18next-chained-backend'
import Vue from 'vue'
import AsyncComputed from 'vue-async-computed'
import VueCookies from 'vue-cookies'
import Vuetify from 'vuetify/lib'

import { get_i18next_options, get_vuetify_options, i18n, store } from 'FerdaJS/app.config'
import AppLogin from 'ferda/auth/AppLogin.vue'

Vue.use(AsyncComputed)
Vue.use(VueCookies)
Vue.use(Vuetify)
Vue.use(Notifications)

const ferda_plugins_el = document.querySelector('#ferda-plugins')
if (ferda_plugins_el) {
    store.commit('general/set_plugins', JSON.parse(ferda_plugins_el.textContent))
}

const current_plugin_el = document.querySelector('#current-plugin')
if (current_plugin_el) {
    store.commit('general/set_current_plugin', JSON.parse(current_plugin_el.textContent))
}

const user_profile_el = document.querySelector('#user-profile')
if (user_profile_el) {
    store.commit('general/set_user', JSON.parse(user_profile_el.textContent))
}

const user_permissions_el = document.querySelector('#user-permissions')
if (user_permissions_el) {
    store.commit('general/set_permissions', JSON.parse(user_permissions_el.textContent))
}

const django_settings_el = document.querySelector('#django-settings')
if (django_settings_el) {
    const settings = JSON.parse(django_settings_el.textContent)
    store.commit('settings/set_time_zone', settings.TIME_ZONE)
    store.commit('settings/set_language_code', settings.LANGUAGE_CODE)
    store.commit('settings/set_languages', settings.LANGUAGES)
    store.commit('settings/set_fido2_authentication', settings.FIDO2_AUTHENTICATION)
    store.commit('settings/set_manual_in_zone_default_duration', settings.MANUAL_IN_ZONE_DEFAULT_DURATION)
}

i18next.use(Backend).init(get_i18next_options())

i18next.on('initialized', () => {
    const login_page_el = document.querySelector('#login-page')
    if (login_page_el) {
        new Vue({
            el: '#login-page',
            vuetify: new Vuetify(get_vuetify_options()),
            i18n,
            store,
            components: { AppLogin },
            render: createElement => {
                const form_errors = JSON.parse(document.querySelector('#form-errors').textContent)
                const username = JSON.parse(document.querySelector('#form-username').textContent)
                return createElement(AppLogin, {
                    props: {
                        form_errors,
                        username,
                    },
                })
            },
        })
    }
})

window.addEventListener('popstate', () => {
    location.reload()
})
