import VueI18Next from '@panter/vue-i18next'
import i18next from 'i18next'
import Fetch from 'i18next-fetch-backend'
import LocalStorageBackend from 'i18next-localstorage-backend'
import Vue from 'vue'
import VueRouter from 'vue-router'
import vuetify_cs from 'vuetify/es5/locale/cs'
import vuetify_en from 'vuetify/es5/locale/en'
import vuetify_colors from 'vuetify/es5/util/colors'
import Vuex, { Store as VuexStore } from 'vuex'
import YAML from 'yaml'

import { Store } from 'FerdaJS/store'
import PageNotFound from 'ferda/common/PageNotFound.vue'

Vue.use(Vuex)
Vue.use(VueI18Next)
Vue.use(VueRouter)

// Setup default settings for router and extend them at module level
export const router = new VueRouter({ mode: 'history', routes: [{ path: '*', component: PageNotFound }] })

export const store = new VuexStore(Store)

export const get_vuetify_options = () => ({
    lang: {
        locales: { en: vuetify_en, cs: vuetify_cs },
        current: store.getters['preferences/selected_language']
            || store.getters['settings/LANGUAGE_CODE']
            || 'en',
    },
    theme: {
        themes: {
            dark: {
                primary: vuetify_colors.blue.base,
                secondary: vuetify_colors.amber.base,
                accent: vuetify_colors.blue.lighten4,
            },
            light: {
                primary: vuetify_colors.blue.base,
                secondary: vuetify_colors.amber.base,
                accent: vuetify_colors.blue.lighten4,
            },
        },
    },
    options: {
        customProperties: true,
    },
})

const ferda_version_el = document.querySelector('#ferda-version')
export const ferda_version = ferda_version_el ? JSON.parse(ferda_version_el.textContent).version : 'no_version'

export const i18n = new VueI18Next(i18next)

export const get_i18next_options = () => ({
    lng: store.getters['preferences/selected_language'],
    fallbackLng: [store.getters['settings/LANGUAGE_CODE'], 'en'],
    ns: [
        'common',
        'notifications',
        'logger',
        'login',
        'search',
        'contact',
        'domain',
        'nsset',
        'keyset',
        'registrar',
        'message',
        'report',
    ],
    defaultNS: 'common',
    backend: {
        backends: [LocalStorageBackend, Fetch],
        backendOptions: [
            {
                versions: store.getters['settings/LANGUAGES'].reduce((language_versions, lang) => {
                    language_versions[lang[0]] = ferda_version
                    return language_versions
                }, {}),
            },
            {
                loadPath: '/static/ferda/locales/{{lng}}/{{ns}}.yml',
                requestOptions: {
                    cache: 'reload',
                },
                parse: data => YAML.parse(data),
            },
        ],
    },
})
