import { ConsoleMixin } from 'ferda/ConsoleMixin'
import { NotificationsMixin } from 'ferda/NotificationsMixin'
import { CLIPBOARD_STATES } from 'ferda/constants'

export const ClipboardMixin = {
    mixins: [ConsoleMixin, NotificationsMixin],
    computed: {
        supports_clipboard_api() {
            return (Boolean)(navigator && navigator.clipboard)
        },
    },
    methods: {
        /**
         * Takes parameters wanted from clipboard and checks whether it is possible to get them.
         *
         * @param { Object } params - Clipboard-defined operation, e.g. 'clipboard-read'
         * @returns { Object }
         */
        async check_clipboard_permission(params) {
            let result
            try {
                result = await navigator.permissions.query(params)
            } catch (error) {
                this.notify_message(this.ERROR_CLIPBOARD_NOT_AVAILABLE)
                this.log_error(error)
                return null
            }

            // Make sure user has reading from clipboard enabled
            if (result.state === CLIPBOARD_STATES.DENIED) {
                this.notify_message(this.ERROR_CLIPBOARD_ACCESS_DENIED)
                return null
            }

            // Proceed if permission is granted or website is trying to interact with clipboard for the first time
            if (result.state !== CLIPBOARD_STATES.GRANTED && result.state !== CLIPBOARD_STATES.PROMPT) {
                this.notify_message(this.ERROR_SOMETHING_WENT_WRONG)
                return null
            }

            return result
        },
        async write_to_clipboard(text) {
            try {
                await navigator.clipboard.writeText(text)
            } catch (error) {
                // Leave the implementation of error to particular places
                // There might be specific error notifications
                throw new Error(error)
            }
        },
    },
}
