import axios from 'axios'
export const HTTP_ERRORS = Object.freeze({ ABORT_ERROR: 'AbortError' })

export const HttpMixin = {
    methods: {
        /**
         * @param {String} url - GET request url
         * @param {Object} config - additional config
         * @param {Array} additional_status_codes - additional accepted status codes
         * @returns Axios promise
         */
        async http_get(url, config = {}, additional_status_codes = []) {
            config.validateStatus = status => this.validate_status(status, additional_status_codes)
            return axios.get(url, config)
        },
        /**
         * @param {String} url - POST request url
         * @param {Object} data - data sent with request
         * @param {Object} config - additional config
         * @param {Array} additional_status_codes - additional accepted status codes
         * @returns Axios promise
         */
        async http_post(url, data = {}, config = {}, additional_status_codes = []) {
            config.validateStatus = status => this.validate_status(status, additional_status_codes)
            return axios.post(url, data, config)
        },
        get_abort_controller() {
            return new AbortController()
        },
        async abort_request(abort_controller) {
            await abort_controller.abort()
        },
        /**
         * Takes catched error and decides whether it is abort error or not
         * It is able to detect both axios and fetch abort errors
         * @param { Object } error - Catched error
         * @returns { Boolean } true / false - Whether it is abort error or not
         */
        is_http_cancel(error) {
            return axios.isCancel(error) || error.name === HTTP_ERRORS.ABORT_ERROR
        },
        validate_status(status, additional_status_codes) {
            return (status >= 200 && status < 300) || additional_status_codes.includes(status)
        },
    },
}
