"""Ferda message views."""
from django.contrib.auth.mixins import LoginRequiredMixin, PermissionRequiredMixin
from django.views.generic import TemplateView

from ferda.backend import SECRETARY


class MessageListView(LoginRequiredMixin, PermissionRequiredMixin, TemplateView):
    """Message list view."""

    permission_required = 'ferda.can_view_registry'
    template_name = 'ferda/messages/list.html'

    def get_context_data(self, **kwargs):
        """Copy recipients to context."""
        context = super().get_context_data(**kwargs)
        message_filters = {
            'type': self.request.GET.get('type', None),
            'created_from': self.request.GET.get('created_from', None),
            'created_to': self.request.GET.get('created_to', None),
            'recipients': self.request.GET.getlist('recipient'),
            'subtypes': self.request.GET.getlist('subtype'),
        }
        context['message_filters'] = message_filters
        context['message_types'] = {
            'email': SECRETARY.get_template_collections(tags=['email']),
            'letter': SECRETARY.get_template_collections(tags=['letter']),
            'sms': SECRETARY.get_template_collections(tags=['sms']),
        }
        return context


class MessageDetailView(LoginRequiredMixin, PermissionRequiredMixin, TemplateView):
    """Message detail view."""

    permission_required = 'ferda.can_view_registry'
    template_name = 'ferda/messages/detail.html'
